State<T> class

Constructors

State(T source)

Properties

context ↔ dynamic
getter/setter pair
errorPos ↔ int
getter/setter pair
errors → List<ParseError>
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastErrorPos ↔ int
getter/setter pair
log ↔ bool
getter/setter pair
minErrorPos ↔ int
getter/setter pair
ok ↔ bool
getter/setter pair
pos ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → T
final

Methods

fail(int pos, int kind, [Object? value, int start = -1, int end = -1]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restoreLastErrorPos(int pos) → void
setLastErrorPos(int pos) → int
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

as<T>(T? value) → T